@@ -22,29 +22,6 @@ OC.L10N.register(
     "Archived messages are moved in:" : "Archived messages are moved in:",
     "Snoozed messages are moved in:" : "Snoozed messages are moved in:",
     "Junk messages are saved in:" : "Junk messages are saved in:",
-    "Auto" : "خودکار",
-    "Name" : "نام",
-    "Mail address" : "Mail address",
-    "name@example.org" : "name@example.org",
-    "Please enter an email of the format name@example.com" : "Please enter an email of the format name@example.com",
-    "Password" : "گذرواژه",
-    "Manual" : "کتابچه راهنمای",
-    "IMAP Settings" : "تنظیمات IMAP",
-    "IMAP Host" : "میزبان IMAP",
-    "IMAP Security" : "امنیت IMAP",
-    "None" : "هیچ‌کدام",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "شروع TLS",
-    "IMAP Port" : "پرت IMAP",
-    "IMAP User" : "کاربر IMAP",
-    "IMAP Password" : "گذرواژه IMAP",
-    "SMTP Settings" : "تنظیمات SMTP",
-    "SMTP Host" : "میزبان SMTP",
-    "SMTP Security" : "امنیت SMTP",
-    "SMTP Port" : "درگاه SMTP",
-    "SMTP User" : "کاربر SMTP",
-    "SMTP Password" : "رمز عبور SMTP",
-    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password.",
     "Connecting" : "Connecting",
     "Reconnect Google account" : "Reconnect Google account",
     "Sign in with Google" : "Sign in with Google",
@@ -69,6 +46,29 @@ OC.L10N.register(
     "Authorization pop-up closed" : "Authorization pop-up closed",
     "Configuration discovery temporarily not available. Please try again later." : "Configuration discovery temporarily not available. Please try again later.",
     "There was an error while setting up your account" : "There was an error while setting up your account",
+    "Auto" : "خودکار",
+    "Name" : "نام",
+    "Mail address" : "Mail address",
+    "name@example.org" : "name@example.org",
+    "Please enter an email of the format name@example.com" : "Please enter an email of the format name@example.com",
+    "Password" : "گذرواژه",
+    "Manual" : "کتابچه راهنمای",
+    "IMAP Settings" : "تنظیمات IMAP",
+    "IMAP Host" : "میزبان IMAP",
+    "IMAP Security" : "امنیت IMAP",
+    "None" : "هیچ‌کدام",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "شروع TLS",
+    "IMAP Port" : "پرت IMAP",
+    "IMAP User" : "کاربر IMAP",
+    "IMAP Password" : "گذرواژه IMAP",
+    "SMTP Settings" : "تنظیمات SMTP",
+    "SMTP Host" : "میزبان SMTP",
+    "SMTP Security" : "امنیت SMTP",
+    "SMTP Port" : "درگاه SMTP",
+    "SMTP User" : "کاربر SMTP",
+    "SMTP Password" : "رمز عبور SMTP",
+    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password.",
     "Account settings" : "تنظیمات حساب",
     "Aliases" : "Aliases",
     "Alias to S/MIME certificate mapping" : "Alias to S/MIME certificate mapping",
@@ -82,7 +82,6 @@ OC.L10N.register(
     "Days after which messages in Trash will automatically be deleted:" : "Days after which messages in Trash will automatically be deleted:",
     "Autoresponder" : "Autoresponder",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days.",
-    "Please connect to a sieve server first." : "Please connect to a sieve server first.",
     "Filters" : "Filters",
     "Mail server" : "سرور پست الکترونیکی",
     "Update alias" : "Update alias",
@@ -95,6 +94,8 @@ OC.L10N.register(
     "Add alias" : "Add alias",
     "Create alias" : "Create alias",
     "Cancel" : "لغو",
+    "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it.",
+    "Could not update preference" : "Could not update preference",
     "Mail settings" : "Mail settings",
     "Accounts" : "حساب‌ها",
     "Add mail account" : "حساب کاربری پست الکترونیکی اضافه کنید",
@@ -110,6 +111,7 @@ OC.L10N.register(
     "Trusted senders" : "Trusted senders",
     "Manage S/MIME certificates" : "Manage S/MIME certificates",
     "Looking for a way to encrypt your emails?" : "Looking for a way to encrypt your emails?",
+    "About" : "About",
     "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
     "Compose new message" : "نوشتن پیام جدید",
     "Newer message" : "پیام جدیدتر",
@@ -121,14 +123,23 @@ OC.L10N.register(
     "Search" : "جستجو",
     "Send" : "ارسال",
     "Refresh" : "تازه‌سازی",
-    "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it.",
-    "Could not update preference" : "Could not update preference",
-    "Select an alias" : "Select an alias",
-    "Update Certificate" : "Update Certificate",
     "No certificate" : "No certificate",
     "Certificate updated" : "Certificate updated",
     "Could not update certificate" : "Could not update certificate",
     "{commonName} - Valid until {expiryDate}" : "{commonName} - Valid until {expiryDate}",
+    "Select an alias" : "Select an alias",
+    "Update Certificate" : "Update Certificate",
+    "Encrypt with S/MIME and send later" : "Encrypt with S/MIME and send later",
+    "Encrypt with S/MIME and send" : "Encrypt with S/MIME and send",
+    "Encrypt with Mailvelope and send later" : "Encrypt with Mailvelope and send later",
+    "Encrypt with Mailvelope and send" : "Encrypt with Mailvelope and send",
+    "Send later" : "Send later",
+    "Message {id} could not be found" : "Message {id} could not be found",
+    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted.",
+    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Any existing formatting (for example bold, italic, underline or inline images) will be removed.",
+    "Turn off formatting" : "Turn off formatting",
+    "Turn off and remove formatting" : "Turn off and remove formatting",
+    "Keep formatting" : "Keep formatting",
     "From" : "از",
     "Select account" : "حساب را انتخاب کنید",
     "To" : "به",
@@ -151,7 +162,6 @@ OC.L10N.register(
     "Upload attachment" : "پیوست را بارگیری کنید",
     "Add attachment from Files" : "پیوست را از پرونده ها اضافه کنید",
     "Smart picker" : "Smart picker",
-    "Send later" : "Send later",
     "Request a read receipt" : "Request a read receipt",
     "Sign message with S/MIME" : "Sign message with S/MIME",
     "Encrypt message with S/MIME" : "Encrypt message with S/MIME",
@@ -162,28 +172,33 @@ OC.L10N.register(
     "Monday morning" : "Monday morning",
     "Custom date and time" : "Custom date and time",
     "Enter a date" : "تاریخ را وارد کنید",
-    "Encrypt with S/MIME and send later" : "Encrypt with S/MIME and send later",
-    "Encrypt with S/MIME and send" : "Encrypt with S/MIME and send",
-    "Encrypt with Mailvelope and send later" : "Encrypt with Mailvelope and send later",
-    "Encrypt with Mailvelope and send" : "Encrypt with Mailvelope and send",
-    "Message {id} could not be found" : "Message {id} could not be found",
-    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted.",
-    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Any existing formatting (for example bold, italic, underline or inline images) will be removed.",
-    "Turn off formatting" : "Turn off formatting",
-    "Turn off and remove formatting" : "Turn off and remove formatting",
-    "Keep formatting" : "Keep formatting",
+    "Choose" : "انتخاب کنید",
     "Choose a file to add as attachment" : "پرونده ای را برای اضافه کردن به عنوان پیوست انتخاب کنید",
     "Choose a file to share as a link" : "Choose a file to share as a link",
-    "Choose" : "انتخاب کنید",
     "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
+    "Untitled message" : "Untitled message",
     "Expand composer" : "Expand composer",
     "Close composer" : "Close composer",
-    "Untitled message" : "Untitled message",
     "Confirm" : "تائید",
     "Plain text" : "متن ساده",
     "Rich text" : "متن غنی",
     "No messages in this mailbox" : "No messages in this mailbox",
     "No messages" : "No messages",
+    "Blind copy recipients only" : "فقط گیرندگان کپی کور",
+    "No subject" : "No subject",
+    "Later today – {timeLocale}" : "Later today – {timeLocale}",
+    "Set reminder for later today" : "Set reminder for later today",
+    "Tomorrow – {timeLocale}" : "Tomorrow – {timeLocale}",
+    "Set reminder for tomorrow" : "Set reminder for tomorrow",
+    "This weekend – {timeLocale}" : "This weekend – {timeLocale}",
+    "Set reminder for this weekend" : "Set reminder for this weekend",
+    "Next week – {timeLocale}" : "Next week – {timeLocale}",
+    "Set reminder for next week" : "Set reminder for next week",
+    "No trash mailbox configured" : "No trash mailbox configured",
+    "Could not delete message" : "Could not delete message",
+    "Could not archive message" : "Could not archive message",
+    "Thread was snoozed" : "Thread was snoozed",
+    "Could not snooze thread" : "Could not snooze thread",
     "Draft: " : "پیش نویس:",
     "Encrypted message" : "Encrypted message",
     "This message is unread" : "This message is unread",
@@ -206,17 +221,6 @@ OC.L10N.register(
     "Create event" : "Create event",
     "Create task" : "وظیفه ایجاد کنید",
     "Download message" : "Download message",
-    "Blind copy recipients only" : "فقط گیرندگان کپی کور",
-    "No subject" : "No subject",
-    "Set reminder for later today" : "Set reminder for later today",
-    "Set reminder for tomorrow" : "Set reminder for tomorrow",
-    "Set reminder for this weekend" : "Set reminder for this weekend",
-    "Set reminder for next week" : "Set reminder for next week",
-    "No trash mailbox configured" : "No trash mailbox configured",
-    "Could not delete message" : "Could not delete message",
-    "Could not archive message" : "Could not archive message",
-    "Thread was snoozed" : "Thread was snoozed",
-    "Could not snooze thread" : "Could not snooze thread",
     "Load more" : "Load more",
     "_Mark {number} read_::_Mark {number} read_" : ["Mark {number} read","Mark {number} read"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Mark {number} unread","Mark {number} unread"],
@@ -228,12 +232,18 @@ OC.L10N.register(
     "_Move {number} thread_::_Move {number} threads_" : ["Move {number} thread","Move {number} threads"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Forward {number} as attachment","Forward {number} as attachment"],
     "Report this bug" : "گزارش این اشکال",
+    "Event created" : "Event created",
+    "Could not create event" : "رویداد ایجاد نشد",
     "All day" : "تمام روز",
     "Select calendar" : "Select calendar",
     "Description" : "شرح",
     "Create" : "ساخت",
-    "Event created" : "Event created",
-    "Could not create event" : "رویداد ایجاد نشد",
+    "This event was updated" : "This event was updated",
+    "{attendeeName} accepted your invitation" : "{attendeeName} accepted your invitation",
+    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} tentatively accepted your invitation",
+    "{attendeeName} declined your invitation" : "{attendeeName} declined your invitation",
+    "{attendeeName} reacted to your invitation" : "{attendeeName} reacted to your invitation",
+    "Failed to save your participation status" : "Failed to save your participation status",
     "You accepted this invitation" : "You accepted this invitation",
     "You tentatively accepted this invitation" : "You tentatively accepted this invitation",
     "You declined this invitation" : "You declined this invitation",
@@ -248,48 +258,42 @@ OC.L10N.register(
     "Tentatively accept" : "Tentatively accept",
     "More options" : "More options",
     "This event is in the past." : "This event is in the past.",
-    "This event was updated" : "This event was updated",
-    "{attendeeName} accepted your invitation" : "{attendeeName} accepted your invitation",
-    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} tentatively accepted your invitation",
-    "{attendeeName} declined your invitation" : "{attendeeName} declined your invitation",
-    "{attendeeName} reacted to your invitation" : "{attendeeName} reacted to your invitation",
-    "Failed to save your participation status" : "Failed to save your participation status",
+    "individual" : "individual",
     "domain" : "domain",
     "Remove" : "حذف",
     "email" : "ایمیل",
-    "individual" : "individual",
     "Itinerary for {type} is not supported yet" : "برنامه سفر برای {نوع yet هنوز پشتیبانی نمی شود",
+    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
+    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
     "Could not open mailbox" : "صندوق پستی امکان پذیر نیست",
     "Loading messages …" : "Loading messages …",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "نمایه سازی پیام های شما این می تواند کمی برای صندوق های پستی بزرگتر کمی طولانی شود.",
-    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
-    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
     "Choose target mailbox" : "Choose target mailbox",
     "No more submailboxes in here" : "No more submailboxes in here",
+    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
     "Important info" : "Important info",
     "Other" : "دیگر",
-    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
+    "Could not send mdn" : "Could not send mdn",
     "The sender of this message has asked to be notified when you read this message." : "The sender of this message has asked to be notified when you read this message.",
     "Notify the sender" : "Notify the sender",
     "You sent a read confirmation to the sender of this message." : "You sent a read confirmation to the sender of this message.",
-    "Could not send mdn" : "Could not send mdn",
+    "Message was snoozed" : "Message was snoozed",
+    "Could not snooze message" : "Could not snooze message",
     "Forward" : "فرستادن",
     "Move message" : "Move message",
     "Translate" : "ترجمه",
     "Forward message as attachment" : "Forward message as attachment",
     "View source" : "View source",
     "Download thread data for debugging" : "Download thread data for debugging",
-    "Message was snoozed" : "Message was snoozed",
-    "Could not snooze message" : "Could not snooze message",
     "Message body" : "Message body",
     "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!",
+    "Unnamed" : "بی نام",
+    "Embedded message" : "پیام درج شده",
+    "calendar imported" : "calendar imported",
     "Choose a folder to store the attachment in" : "لطفا پوشه ای را برای ذخیره سازی ضمیمه انتخاب کنید",
     "Import into calendar" : "وارد تقویم شوید",
     "Download attachment" : "پیوست را بارگیری کنید",
     "Save to Files" : "ذخیره در پرونده ها",
-    "Unnamed" : "بی نام",
-    "Embedded message" : "پیام درج شده",
-    "calendar imported" : "calendar imported",
     "View fewer attachments" : "View fewer attachments",
     "Choose a folder to store the attachments in" : "پوشه ای را برای ذخیره کردن پیوست ها انتخاب کنید",
     "Save all to Files" : "ذخیره همه در پرونده ها",
@@ -307,6 +311,12 @@ OC.L10N.register(
     "Moving" : "Moving",
     "Moving thread" : "Moving thread",
     "Moving message" : "Moving message",
+    "Loading …" : "بارگذاری …",
+    "Not supported by the server" : "Not supported by the server",
+    "{usage} of {limit} used" : "{usage} of {limit} used",
+    "Remove account" : "حذف حساب کاربری",
+    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider.",
+    "Remove {email}" : "Remove {email}",
     "Provisioned account is disabled" : "Provisioned account is disabled",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn.",
     "Quota" : "سهم",
@@ -315,15 +325,18 @@ OC.L10N.register(
     "Saving" : "درحال ذخیره",
     "Move up" : "Move up",
     "Move down" : "حرکت به پایین",
-    "Remove account" : "حذف حساب کاربری",
-    "Loading …" : "بارگذاری …",
-    "Not supported by the server" : "Not supported by the server",
-    "{usage} of {limit} used" : "{usage} of {limit} used",
-    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider.",
-    "Remove {email}" : "Remove {email}",
     "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
     "Show all mailboxes" : "Show all mailboxes",
     "Collapse mailboxes" : "Collapse mailboxes",
+    "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
+    "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
+    "Clear mailbox {name}" : "Clear mailbox {name}",
+    "Clear mailbox" : "Clear mailbox",
+    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
+    "Delete mailbox" : "Delete mailbox",
+    "Delete mailbox {name}" : "Delete mailbox {name}",
+    "An error occurred, unable to rename the mailbox." : "An error occurred, unable to rename the mailbox.",
     "Mark all as read" : "علامت همه به عنوان خوانده‌شده",
     "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
     "Add submailbox" : "Add submailbox",
@@ -333,23 +346,8 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Clear locally cached data, in case there are issues with synchronization.",
     "Subscribed" : "Subscribed",
     "Sync in background" : "Sync in background",
-    "Clear mailbox" : "Clear mailbox",
-    "Delete mailbox" : "Delete mailbox",
-    "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
-    "Clear mailbox {name}" : "Clear mailbox {name}",
-    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
-    "Delete mailbox {name}" : "Delete mailbox {name}",
-    "An error occurred, unable to rename the mailbox." : "An error occurred, unable to rename the mailbox.",
-    "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
     "Outbox" : "Outbox",
     "New message" : "پیام جدید",
-    "Error sending your message" : "خطایی در ارسال پیام شما",
-    "Retry" : "تلاش دوباره",
-    "Uploading attachments …" : "درحال بارگذاری پیوستها …",
-    "Sending …" : "در حال ارسال ...",
-    "Warning sending your message" : "Warning sending your message",
-    "Send anyway" : "Send anyway",
-    "Minimize composer" : "Minimize composer",
     "Edit message" : "Edit message",
     "Draft" : "Draft",
     "Reply" : "پاسخ",
@@ -360,6 +358,13 @@ OC.L10N.register(
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses.",
     "Message discarded" : "Message discarded",
     "Could not discard message" : "Could not discard message",
+    "Error sending your message" : "خطایی در ارسال پیام شما",
+    "Retry" : "تلاش دوباره",
+    "Uploading attachments …" : "درحال بارگذاری پیوستها …",
+    "Sending …" : "در حال ارسال ...",
+    "Warning sending your message" : "Warning sending your message",
+    "Send anyway" : "Send anyway",
+    "Minimize composer" : "Minimize composer",
     "Autoresponder off" : "Autoresponder off",
     "Autoresponder on" : "Autoresponder on",
     "First day" : "First day",
@@ -372,16 +377,17 @@ OC.L10N.register(
     "Pending or not sent messages will show up here" : "Pending or not sent messages will show up here",
     "Message could not be sent" : "Message could not be sent",
     "Message deleted" : "Message deleted",
+    "Copied email address to clipboard" : "Copied email address to clipboard",
+    "Could not copy email address to clipboard" : "Could not copy email address to clipboard",
     "Contacts with this address" : "Contacts with this address",
     "Add to Contact" : "Add to Contact",
     "New Contact" : "New Contact",
     "Copy to clipboard" : "کپی کردن به حافظه موقت",
     "Contact name …" : "Contact name …",
     "Add" : "افزودن",
-    "Copied email address to clipboard" : "Copied email address to clipboard",
-    "Could not copy email address to clipboard" : "Could not copy email address to clipboard",
     "Show less" : "Show less",
     "Show more" : "Show more",
+    "Clear" : "پاک کردن",
     "Search in mailbox" : "Search in mailbox",
     "Close" : "بسته",
     "Search parameters" : "Search parameters",
@@ -398,38 +404,45 @@ OC.L10N.register(
     "Marked as" : "Marked as",
     "Has attachments" : "Has attachments",
     "Last 7 days" : "۷ روز گذشته",
-    "Clear" : "پاک کردن",
     "Sieve Port" : "Sieve Port",
     "Custom" : "Custom",
     "Sieve User" : "Sieve User",
     "Sieve Password" : "Sieve Password",
     "Save sieve settings" : "Save sieve settings",
-    "Save sieve script" : "Save sieve script",
     "The syntax seems to be incorrect:" : "The syntax seems to be incorrect:",
+    "Save sieve script" : "Save sieve script",
     "Signature …" : "امضا ...",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Your signature is larger than 2 MB. This may affect the performance of your editor.",
     "Save signature" : "ذخیره امضا",
     "Place signature above quoted text" : "Place signature above quoted text",
+    "An error occurred, unable to rename the tag." : "An error occurred, unable to rename the tag.",
     "Saving new tag name …" : "Saving new tag name …",
     "Set tag" : "Set tag",
     "Unset tag" : "Unset tag",
-    "An error occurred, unable to rename the tag." : "An error occurred, unable to rename the tag.",
-    "Add default tags" : "Add default tags",
-    "Add tag" : "برچسب اضافه کنید",
-    "Saving tag …" : "Saving tag …",
     "Tag name is a hidden system tag" : "Tag name is a hidden system tag",
     "Tag already exists" : "تگ از قبل وجود دارد",
     "An error occurred, unable to create the tag." : "An error occurred, unable to create the tag.",
-    "No calendars with task list support" : "No calendars with task list support",
+    "Add default tags" : "Add default tags",
+    "Add tag" : "برچسب اضافه کنید",
+    "Saving tag …" : "Saving tag …",
     "Task created" : "Task created",
     "Could not create task" : "Could not create task",
-    "Loading thread" : "Loading thread",
-    "Not found" : "پیدا نشد",
+    "No calendars with task list support" : "No calendars with task list support",
     "Summarizing thread failed." : "Summarizing thread failed.",
     "Could not load your message thread" : "Could not load your message thread",
     "The thread doesn't exist or has been deleted" : "The thread doesn't exist or has been deleted",
-    "Unsubscribe" : "Unsubscribe",
+    "Loading thread" : "Loading thread",
+    "Not found" : "پیدا نشد",
+    "Encrypted & verified " : "Encrypted & verified ",
+    "Signature verified" : "Signature verified",
+    "Signature unverified " : "Signature unverified ",
+    "This message was encrypted by the sender before it was sent." : "This message was encrypted by the sender before it was sent.",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent.",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted.",
     "Reply all" : "Reply all",
+    "Unsubscribe request sent" : "Unsubscribe request sent",
+    "Could not unsubscribe from mailing list" : "Could not unsubscribe from mailing list",
+    "Unsubscribe" : "Unsubscribe",
     "Reply to sender only" : "فقط به فرستنده پاسخ دهید",
     "Mark as unfavorite" : "Mark as unfavorite",
     "Mark as favorite" : "Mark as favorite",
@@ -442,17 +455,12 @@ OC.L10N.register(
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Unsubscribing will stop all messages from the mailing list {sender}",
     "Send unsubscribe email" : "Send unsubscribe email",
     "Unsubscribe via email" : "Unsubscribe via email",
-    "Encrypted & verified " : "Encrypted & verified ",
-    "Signature verified" : "Signature verified",
-    "Signature unverified " : "Signature unverified ",
-    "This message was encrypted by the sender before it was sent." : "This message was encrypted by the sender before it was sent.",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent.",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted.",
-    "Unsubscribe request sent" : "Unsubscribe request sent",
-    "Could not unsubscribe from mailing list" : "Could not unsubscribe from mailing list",
+    "{name} Assistant" : "{name} Assistant",
     "Go to latest message" : "Go to latest message",
     "Go to newest message" : "Go to newest message",
-    "{name} Assistant" : "{name} Assistant",
+    "The message could not be translated" : "The message could not be translated",
+    "Translation copied to clipboard" : "Translation copied to clipboard",
+    "Translation could not be copied" : "Translation could not be copied",
     "Translate message" : "Translate message",
     "Source language to translate from" : "Source language to translate from",
     "Translate from" : "Translate from",
@@ -460,28 +468,29 @@ OC.L10N.register(
     "Translate to" : "Translate to",
     "Translating" : "Translating",
     "Copy translated text" : "رونوشت متن ترجمه",
-    "The message could not be translated" : "The message could not be translated",
-    "Translation copied to clipboard" : "Translation copied to clipboard",
-    "Translation could not be copied" : "Translation could not be copied",
     "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed.",
-    "No senders are trusted at the moment." : "No senders are trusted at the moment.",
     "Could not remove trusted sender {sender}" : "Could not remove trusted sender {sender}",
-    "(organizer)" : "(تنظیم کننده)",
+    "No senders are trusted at the moment." : "No senders are trusted at the moment.",
     "Untitled event" : "رویداد بدون عنوان",
+    "(organizer)" : "(تنظیم کننده)",
     "Import into {calendar}" : "{وارد {تقویم",
     "Event imported into {calendar}" : "{رویداد وارد شده به {تقویم",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{پرواز} {پرواز Nr} از {depAirport} به {arrAirport}",
     "Airplane" : "هواپیما",
     "Reservation {id}" : "رزرو {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{پرواز} {پرواز Nr} از {depAirport} به {arrAirport}",
-    "Train" : "رشته",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} از {depStation} تا {arrStation}",
     "Train from {depStation} to {arrStation}" : "آموزش از {depStation} تا {arrStation} Train",
+    "Train" : "رشته",
     "Flag" : "Flag",
     "Delete filter" : "Delete filter",
     "Operator" : "Operator",
     "Actions" : "کنش‌ها",
     "New action" : "New action",
     "Priority" : "اولویت",
+    "Successfully updated config for \"{domain}\"" : "Successfully updated config for \"{domain}\"",
+    "Error saving config" : "Error saving config",
+    "Saved config for \"{domain}\"" : "Saved config for \"{domain}\"",
+    "Could not save provisioning setting" : "Could not save provisioning setting",
     "Mail app" : "برنامه پست الکترونیکی",
     "The mail app allows users to read mails on their IMAP accounts." : "برنامه نامه الکترونیکی به کاربران این امکان را می دهد تا نامه ها را در حساب های IMAP خود بخوانند.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner).",
@@ -503,10 +512,10 @@ OC.L10N.register(
     "Microsoft integration" : "Microsoft integration",
     "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection.",
     "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI.",
-    "Successfully updated config for \"{domain}\"" : "Successfully updated config for \"{domain}\"",
-    "Error saving config" : "Error saving config",
-    "Saved config for \"{domain}\"" : "Saved config for \"{domain}\"",
-    "Could not save provisioning setting" : "Could not save provisioning setting",
+    "Successfully set up anti spam email addresses" : "Successfully set up anti spam email addresses",
+    "Error saving anti spam email addresses" : "Error saving anti spam email addresses",
+    "Successfully deleted anti spam reporting email" : "Successfully deleted anti spam reporting email",
+    "Error deleting anti spam reporting email" : "Error deleting anti spam reporting email",
     "Anti Spam" : "Anti Spam",
     "Add the email address of your anti spam report service here." : "Add the email address of your anti spam report service here.",
     "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\".",
@@ -514,22 +523,18 @@ OC.L10N.register(
     "\"Mark as Spam\" Email Address" : "\"Mark as Spam\" Email Address",
     "\"Mark Not Junk\" Email Address" : "\"Mark Not Junk\" Email Address",
     "Reset" : "بازنشاندن",
-    "Successfully set up anti spam email addresses" : "Successfully set up anti spam email addresses",
-    "Error saving anti spam email addresses" : "Error saving anti spam email addresses",
-    "Successfully deleted anti spam reporting email" : "Successfully deleted anti spam reporting email",
-    "Error deleting anti spam reporting email" : "Error deleting anti spam reporting email",
-    "Client ID" : "شناسه مشتری",
-    "Client secret" : "رمز مشتری",
-    "Unlink" : "Unlink",
     "Google integration configured" : "Google integration configured",
     "Could not configure Google integration" : "Could not configure Google integration",
     "Google integration unlinked" : "Google integration unlinked",
     "Could not unlink Google integration" : "Could not unlink Google integration",
-    "Tenant ID (optional)" : "Tenant ID (optional)",
+    "Client ID" : "شناسه مشتری",
+    "Client secret" : "رمز مشتری",
+    "Unlink" : "Unlink",
     "Microsoft integration configured" : "Microsoft integration configured",
     "Could not configure Microsoft integration" : "Could not configure Microsoft integration",
     "Microsoft integration unlinked" : "Microsoft integration unlinked",
     "Could not unlink Microsoft integration" : "Could not unlink Microsoft integration",
+    "Tenant ID (optional)" : "Tenant ID (optional)",
     "Domain Match: {provisioningDomain}" : "Domain Match: {provisioningDomain}",
     "Email: {email}" : "ایمیل: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} on {host}: {port} (رمزگذاری {ssl))",
@@ -554,6 +559,11 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "Unprovision & Delete Config",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% and %EMAIL% will be replaced with the user's UID and email",
     "With the settings above, the app will create account settings in the following way:" : "با تنظیمات فوق ، برنامه تنظیمات حساب را به روش زیر ایجاد می کند:",
+    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key.",
+    "Failed to import the certificate. Please check the password." : "Failed to import the certificate. Please check the password.",
+    "Certificate imported successfully" : "Certificate imported successfully",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase.",
+    "Failed to import the certificate" : "Failed to import the certificate",
     "S/MIME certificates" : "S/MIME certificates",
     "Certificate name" : "Certificate name",
     "E-mail address" : "آدرس ایمیل",
@@ -568,19 +578,10 @@ OC.L10N.register(
     "Private key (optional)" : "Private key (optional)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "The private key is only required if you intend to send signed and encrypted emails using this certificate.",
     "Submit" : "ارسال",
-    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key.",
-    "Failed to import the certificate. Please check the password." : "Failed to import the certificate. Please check the password.",
-    "Certificate imported successfully" : "Certificate imported successfully",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase.",
-    "Failed to import the certificate" : "Failed to import the certificate",
     "Account connected" : "Account connected",
     "You can close this window" : "You can close this window",
     "Connect your mail account" : "حساب ایمیل خود را وصل کنید",
     "To add a mail account, please contact your administrator." : "To add a mail account, please contact your administrator.",
-    "Next week – {timeLocale}" : "Next week – {timeLocale}",
-    "This weekend – {timeLocale}" : "This weekend – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Tomorrow – {timeLocale}",
-    "Later today – {timeLocale}" : "Later today – {timeLocale}",
     "All" : "همه",
     "Drafts" : "پیش نویس",
     "Favorites" : "علاقه مندی ها",
@@ -613,7 +614,6 @@ OC.L10N.register(
     "Redirect" : "تغییر مسیر",
     "The link leads to %s" : "پیوند منجر به%s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
-    "Continue to %s" : "ادامه دهید%s",
-    "Unselect" : "لغو انتخاب"
+    "Continue to %s" : "ادامه دهید%s"
 },
 "nplurals=2; plural=(n > 1);");
