@@ -19,6 +19,25 @@ OC.L10N.register(
     "Sent messages are saved in:" : "Lähetetyt viestit tallennetaan sijaintiin:",
     "Deleted messages are moved in:" : "Poistetut viestit tallennetaan sijaintiin:",
     "Archived messages are moved in:" : "Siirrä arkistoidut viestit:",
+    "Connecting" : "Yhdistetään",
+    "Reconnect Google account" : "Yhdistä Google-tili uudelleen",
+    "Sign in with Google" : "Kirjaudu sisään Google-tililläsi",
+    "Save" : "Tallenna",
+    "Connect" : "Yhdistä",
+    "Looking up configuration" : "Etsitään määrityksiä",
+    "Password required" : "Salasana vaaditaan",
+    "Testing authentication" : "Testataan tunnistautumista",
+    "Awaiting user consent" : "Odotetaan käyttäjän hyväksyntää",
+    "Loading account" : "Ladataan tiliä",
+    "Account updated" : "Tili päivitetty",
+    "IMAP server is not reachable" : "IMAP-palvelin ei ole tavoitettavissa",
+    "SMTP server is not reachable" : "SMTP-palvelin ei ole tavoitettavissa",
+    "IMAP username or password is wrong" : "IMAP-käyttäjätunnus tai -salasana on väärin",
+    "SMTP username or password is wrong" : "SMTP-käyttäjätunnus tai -salasana on väärin",
+    "IMAP connection failed" : "IMAP-yhteys epäonnistui",
+    "SMTP connection failed" : "SMTP-yhteys epäonnistui",
+    "Authorization pop-up closed" : "Valtuutusikkuna suljettu",
+    "There was an error while setting up your account" : "Tiliä määrittäessä ilmeni virhe",
     "Auto" : "Automaattinen",
     "Name" : "Nimi",
     "Mail address" : "Sähköpostiosoite",
@@ -42,25 +61,6 @@ OC.L10N.register(
     "SMTP User" : "SMTP-käyttäjä",
     "SMTP Password" : "SMTP-salasana",
     "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Google-tilin toiminta tämän sovelluksen kanssa vaatii, että otat kaksivaiheisen todennuksen käyttöön Googlessa ja luot sovelluksen salasanan.",
-    "Connecting" : "Yhdistetään",
-    "Reconnect Google account" : "Yhdistä Google-tili uudelleen",
-    "Sign in with Google" : "Kirjaudu sisään Google-tililläsi",
-    "Save" : "Tallenna",
-    "Connect" : "Yhdistä",
-    "Looking up configuration" : "Etsitään määrityksiä",
-    "Password required" : "Salasana vaaditaan",
-    "Testing authentication" : "Testataan tunnistautumista",
-    "Awaiting user consent" : "Odotetaan käyttäjän hyväksyntää",
-    "Loading account" : "Ladataan tiliä",
-    "Account updated" : "Tili päivitetty",
-    "IMAP server is not reachable" : "IMAP-palvelin ei ole tavoitettavissa",
-    "SMTP server is not reachable" : "SMTP-palvelin ei ole tavoitettavissa",
-    "IMAP username or password is wrong" : "IMAP-käyttäjätunnus tai -salasana on väärin",
-    "SMTP username or password is wrong" : "SMTP-käyttäjätunnus tai -salasana on väärin",
-    "IMAP connection failed" : "IMAP-yhteys epäonnistui",
-    "SMTP connection failed" : "SMTP-yhteys epäonnistui",
-    "Authorization pop-up closed" : "Valtuutusikkuna suljettu",
-    "There was an error while setting up your account" : "Tiliä määrittäessä ilmeni virhe",
     "Account settings" : "Tilin asetukset",
     "Aliases" : "Aliakset",
     "Signature" : "Allekirjoitus",
@@ -79,6 +79,8 @@ OC.L10N.register(
     "Add alias" : "Lisää alias",
     "Create alias" : "Luo alias",
     "Cancel" : "Peruuta",
+    "Put my text to the bottom of a reply instead of on top of it." : "Aseta tekstini vastauksen alaosaan yläosan sijaan",
+    "Could not update preference" : "Asetuksia ei voitu päivittää",
     "Mail settings" : "Sähköpostin asetukset",
     "Accounts" : "Tilit",
     "Add mail account" : "Lisää sähköpostitili",
@@ -93,6 +95,7 @@ OC.L10N.register(
     "Trusted senders" : "Luotetut lähettäjät",
     "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
     "Looking for a way to encrypt your emails?" : "Etsitkö tapaa salata sähköpostisi?",
+    "About" : "Tietoja",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Compose new message" : "Uusi viesti",
     "Newer message" : "Uudempi",
@@ -104,13 +107,21 @@ OC.L10N.register(
     "Search" : "Etsi",
     "Send" : "Lähetä",
     "Refresh" : "Päivitä",
-    "Put my text to the bottom of a reply instead of on top of it." : "Aseta tekstini vastauksen alaosaan yläosan sijaan",
-    "Could not update preference" : "Asetuksia ei voitu päivittää",
-    "Update Certificate" : "Päivitä varmenne",
     "No certificate" : "Ei varmennetta",
     "Certificate updated" : "Varmenne päivitetty",
     "Could not update certificate" : "Varmennetta ei voitu päivittää",
     "{commonName} - Valid until {expiryDate}" : "{commonName} - Kelvollinen {expiryDate} asti",
+    "Update Certificate" : "Päivitä varmenne",
+    "Encrypt with S/MIME and send later" : "Salaa S/MIME:llä ja lähetä myöhemmin",
+    "Encrypt with S/MIME and send" : "Salaa S/MIME:llä ja lähetä",
+    "Encrypt with Mailvelope and send later" : "Salaa Mailvelopella ja lähetä myöhemmin",
+    "Encrypt with Mailvelope and send" : "Salaa Mailvelopella ja lähetä",
+    "Send later" : "Lähetä myöhemmin",
+    "Message {id} could not be found" : "Viestiä {id} ei löytynyt",
+    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Mikä tahansa aiempi muotoilu (esimerkiksi lihavointi, kursivointi, alleviivaus tai sisennetyt kuvat) poistetaan.",
+    "Turn off formatting" : "Poista muotoilu käytöstä",
+    "Turn off and remove formatting" : "Poista käytöstä ja poista muotoilu",
+    "Keep formatting" : "Säilytä muotoilu",
     "From" : "Lähettäjä",
     "Select account" : "Valitse tili",
     "To" : "Vastaanottaja",
@@ -133,7 +144,6 @@ OC.L10N.register(
     "Disable formatting" : "Poista muotoilu käytöstä",
     "Upload attachment" : "Lähetä liite",
     "Add attachment from Files" : "Lisää liitteitä tiedostosovelluksesta",
-    "Send later" : "Lähetä myöhemmin",
     "Request a read receipt" : "Pyydä lukukuittaus",
     "Sign message with S/MIME" : "Allekirjoita viesti S/MIME:llä",
     "Encrypt message with S/MIME" : "Salaa viesti S/MIME:llä",
@@ -144,27 +154,30 @@ OC.L10N.register(
     "Monday morning" : "Maanantaiaamuna",
     "Custom date and time" : "Omavalintainen päivä ja aika",
     "Enter a date" : "Kirjoita päiväys",
-    "Encrypt with S/MIME and send later" : "Salaa S/MIME:llä ja lähetä myöhemmin",
-    "Encrypt with S/MIME and send" : "Salaa S/MIME:llä ja lähetä",
-    "Encrypt with Mailvelope and send later" : "Salaa Mailvelopella ja lähetä myöhemmin",
-    "Encrypt with Mailvelope and send" : "Salaa Mailvelopella ja lähetä",
-    "Message {id} could not be found" : "Viestiä {id} ei löytynyt",
-    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Mikä tahansa aiempi muotoilu (esimerkiksi lihavointi, kursivointi, alleviivaus tai sisennetyt kuvat) poistetaan.",
-    "Turn off formatting" : "Poista muotoilu käytöstä",
-    "Turn off and remove formatting" : "Poista käytöstä ja poista muotoilu",
-    "Keep formatting" : "Säilytä muotoilu",
+    "Choose" : "Valitse",
     "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
     "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
-    "Choose" : "Valitse",
     "_{count} attachment_::_{count} attachments_" : ["{count} liite","{count} liitettä"],
+    "Untitled message" : "Nimetön viesti",
     "Expand composer" : "Laajenna lähetysikkunaa",
     "Close composer" : "Sulje lähetysikkuna",
-    "Untitled message" : "Nimetön viesti",
     "Confirm" : "Vahvista",
     "Plain text" : "Raakateksti",
     "Rich text" : "Rikas teksti",
     "No messages in this mailbox" : "Ei viestejä tässä postilaatikossa",
     "No messages" : "Ei viestejä",
+    "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
+    "No subject" : "Ei aihetta",
+    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
+    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
+    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
+    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
+    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
+    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
+    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
+    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
+    "Could not delete message" : "Ei voitu poistaa viestiä",
+    "Could not archive message" : "Viestiä ei voitu arkistoida",
     "Draft: " : "Luonnos: ",
     "Encrypted message" : "Salattu viesti",
     "This message is unread" : "Tämä viesti on lukematon",
@@ -187,25 +200,22 @@ OC.L10N.register(
     "Create event" : "Luo tapahtuma",
     "Create task" : "Luo tehtävä",
     "Download message" : "Lataa viesti",
-    "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
-    "No subject" : "Ei aihetta",
-    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
-    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
-    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
-    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
-    "Could not delete message" : "Ei voitu poistaa viestiä",
-    "Could not archive message" : "Viestiä ei voitu arkistoida",
     "Load more" : "Lataa lisää",
     "_Mark {number} read_::_Mark {number} read_" : ["Merkitse {number} luetuksi","Merkitse {number} luetuksi"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Merkitse {number} lukemattomaksi","Merkitse {number} lukemattomaksi"],
     "_Mark {number} as important_::_Mark {number} as important_" : ["Merkitse {number} tärkeäksi","Merkitse {number} tärkeäksi"],
     "Report this bug" : "Ilmoita viasta",
+    "Event created" : "Tapahtuma luotu",
+    "Could not create event" : "Tapahtumaa ei voitu luoda",
     "All day" : "Koko päivä",
     "Select calendar" : "Valitse kalenteri",
     "Description" : "Kuvaus",
     "Create" : "Luo",
-    "Event created" : "Tapahtuma luotu",
-    "Could not create event" : "Tapahtumaa ei voitu luoda",
+    "This event was updated" : "Tämä tapahtuma päivitettiin",
+    "{attendeeName} accepted your invitation" : "{attendeeName} hyväksyi kutsusi",
+    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} hyväksyi kutsusi alustavasti",
+    "{attendeeName} declined your invitation" : "{attendeeName} kieltäytyi kutsustasi",
+    "{attendeeName} reacted to your invitation" : "{attendeeName} reagoi kutsuusi",
     "You accepted this invitation" : "Hyväksyit tämän kutsun",
     "You tentatively accepted this invitation" : "Hyväksyit tämän kutsun alustavasti",
     "You declined this invitation" : "Kieltäydyit tästä kutsusta",
@@ -219,15 +229,10 @@ OC.L10N.register(
     "Tentatively accept" : "Alustavasti hyväksytty",
     "More options" : "Lisää valintoja",
     "This event is in the past." : "Tämä tapahtuma on menneisyydessä.",
-    "This event was updated" : "Tämä tapahtuma päivitettiin",
-    "{attendeeName} accepted your invitation" : "{attendeeName} hyväksyi kutsusi",
-    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} hyväksyi kutsusi alustavasti",
-    "{attendeeName} declined your invitation" : "{attendeeName} kieltäytyi kutsustasi",
-    "{attendeeName} reacted to your invitation" : "{attendeeName} reagoi kutsuusi",
+    "individual" : "yksittäinen",
     "domain" : "domaini",
     "Remove" : "Poista",
     "email" : "sähköposti",
-    "individual" : "yksittäinen",
     "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
     "Loading messages …" : "Ladataan viestejä …",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
@@ -243,12 +248,12 @@ OC.L10N.register(
     "View source" : "Näytä lähde",
     "Download thread data for debugging" : "Lataa ketjun data vianjäljitystä varten",
     "Message body" : "Viestin runko",
+    "Unnamed" : "Nimetön",
+    "Embedded message" : "Upotettu viesti",
     "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
     "Import into calendar" : "Tuo kalenteriin",
     "Download attachment" : "Lataa liite",
     "Save to Files" : "Tallenna tiedostoihin",
-    "Unnamed" : "Nimetön",
-    "Embedded message" : "Upotettu viesti",
     "View fewer attachments" : "Näytä vähemmän liitteitä",
     "Choose a folder to store the attachments in" : "Valitse kansio johon liitteet tallennetaan",
     "Save all to Files" : "Tallenna kaikki tiedostoihin",
@@ -266,21 +271,30 @@ OC.L10N.register(
     "Moving" : "Siirretään",
     "Moving thread" : "Siirretään ketjua",
     "Moving message" : "Siirretään viestiä",
+    "Loading …" : "Ladataan…",
+    "Not supported by the server" : "Ei tuettu palvelimen toimesta",
+    "{usage} of {limit} used" : "{usage}/{limit} käytetty",
+    "Remove account" : "Poista tili",
+    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tili {email} ja tallennetut viesti poistetaan Nextcloudista, muttei sähköpostintarjoajaltasi.",
+    "Remove {email}" : "Poista {email}",
     "Quota" : "Kiintiö",
     "Show only subscribed mailboxes" : "Näytä vain tilatut postilaatikot",
     "Add mailbox" : "Lisää postilaatikko",
     "Saving" : "Tallennetaan",
     "Move up" : "Siirrä ylös",
     "Move down" : "Siirrä alas",
-    "Remove account" : "Poista tili",
-    "Loading …" : "Ladataan…",
-    "Not supported by the server" : "Ei tuettu palvelimen toimesta",
-    "{usage} of {limit} used" : "{usage}/{limit} käytetty",
-    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tili {email} ja tallennetut viesti poistetaan Nextcloudista, muttei sähköpostintarjoajaltasi.",
-    "Remove {email}" : "Poista {email}",
     "Show all subscribed mailboxes" : "Näytä kaikki tilatut postilaatikot",
     "Show all mailboxes" : "Näytä kaikki postilaatikot",
     "Collapse mailboxes" : "Supista postilaatikot",
+    "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
+    "All messages in mailbox will be deleted." : "Kaikki postilaatikon viestit poistetaan.",
+    "Clear mailbox {name}" : "Tyhjennä postilaatikko {name}",
+    "Clear mailbox" : "Tyhjennä postilaatikko",
+    "The mailbox and all messages in it will be deleted." : "Tämä postilaatikko ja kaikki sen viestit poistetaan.",
+    "Delete mailbox" : "Poista postilaatikko",
+    "Delete mailbox {name}" : "Poista postilaatikko {name}",
+    "An error occurred, unable to rename the mailbox." : "Tapahtui virhe. Postilaatikon nimeäminen uudelleen ei onnistunut.",
     "Mark all as read" : "Merkitse kaikki luetuiksi",
     "Mark all messages of this mailbox as read" : "Merkitse kaikki tämän postilaatikon viestit luetuiksi",
     "Add submailbox" : "Lisää alipostilaatikko",
@@ -289,22 +303,7 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Poista paikallisesti tallennetut tiedot, jos synkronoinnissa on ongelmia.",
     "Subscribed" : "Tilattu",
     "Sync in background" : "Synkronoi taustalla",
-    "Clear mailbox" : "Tyhjennä postilaatikko",
-    "Delete mailbox" : "Poista postilaatikko",
-    "All messages in mailbox will be deleted." : "Kaikki postilaatikon viestit poistetaan.",
-    "Clear mailbox {name}" : "Tyhjennä postilaatikko {name}",
-    "The mailbox and all messages in it will be deleted." : "Tämä postilaatikko ja kaikki sen viestit poistetaan.",
-    "Delete mailbox {name}" : "Poista postilaatikko {name}",
-    "An error occurred, unable to rename the mailbox." : "Tapahtui virhe. Postilaatikon nimeäminen uudelleen ei onnistunut.",
-    "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
     "New message" : "Uusi viesti",
-    "Error sending your message" : "Virhe viestiäsi lähettäessä",
-    "Retry" : "Yritä uudelleen",
-    "Uploading attachments …" : "Lähetetään liitteitä…",
-    "Sending …" : "Lähetetään…",
-    "Warning sending your message" : "Varoitus viestiä lähettäessä",
-    "Send anyway" : "Lähetä silti",
-    "Minimize composer" : "Pienennä lähetysikkuna",
     "Edit message" : "Muokkaa viestiä",
     "Draft" : "Luonnos",
     "Reply" : "Vastaa",
@@ -314,6 +313,13 @@ OC.L10N.register(
     "No sent mailbox configured. Please pick one in the account settings." : "Ei postilaatikkoa lähetetyille määritetty. Valitse se tilin asetuksista.",
     "Message discarded" : "Viesti hylätty",
     "Could not discard message" : "Viestiä ei voitu hylätä",
+    "Error sending your message" : "Virhe viestiäsi lähettäessä",
+    "Retry" : "Yritä uudelleen",
+    "Uploading attachments …" : "Lähetetään liitteitä…",
+    "Sending …" : "Lähetetään…",
+    "Warning sending your message" : "Varoitus viestiä lähettäessä",
+    "Send anyway" : "Lähetä silti",
+    "Minimize composer" : "Pienennä lähetysikkuna",
     "Autoresponder off" : "Automaattivastaukset pois päältä",
     "Autoresponder on" : "Automaattivastaukset päällä",
     "First day" : "Ensimmäinen päivä",
@@ -324,16 +330,17 @@ OC.L10N.register(
     "Pending or not sent messages will show up here" : "Odottavat tai vielä lähettämättömät viestit näkyvät täällä",
     "Message could not be sent" : "Viestiä ei voitu lähettää",
     "Message deleted" : "Viesti poistettu",
+    "Copied email address to clipboard" : "Sähköpostiosoite kopioitu leikepöydälle",
+    "Could not copy email address to clipboard" : "Sähköpostiosoitetta ei voitu kopioida leikepöydälle",
     "Contacts with this address" : "Yhteystiedot tällä osoitteella",
     "Add to Contact" : "Lisää yhteystietoon",
     "New Contact" : "Uusi yhteystieto",
     "Copy to clipboard" : "Kopioi leikepöydälle",
     "Contact name …" : "Yhteystiedon nimi…",
     "Add" : "Lisää",
-    "Copied email address to clipboard" : "Sähköpostiosoite kopioitu leikepöydälle",
-    "Could not copy email address to clipboard" : "Sähköpostiosoitetta ei voitu kopioida leikepöydälle",
     "Show less" : "Näytä vähemmän",
     "Show more" : "Näytä enemmän",
+    "Clear" : "Tyhjennä",
     "Close" : "Sulje",
     "Body" : "Sisältö",
     "Date" : "Päivä",
@@ -343,7 +350,6 @@ OC.L10N.register(
     "Select tags" : "Valitse tunnisteet",
     "Has attachments" : "On liitteitä",
     "Last 7 days" : "Edelliset 7 päivää",
-    "Clear" : "Tyhjennä",
     "Sieve Port" : "Sieve-portti",
     "IMAP credentials" : "IMAP-tunnukset",
     "Custom" : "Omavalintainen",
@@ -354,22 +360,26 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Allekirjoituksesi koko on yli kaksi megatavua. Tämä saattaa vaikuttaa muokkaimen suorituskykyyn.",
     "Save signature" : "Tallenna allekirjoitus",
     "Place signature above quoted text" : "Aseta allekirjoitus lainatun tekstin yläpuolelle",
+    "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
     "Saving new tag name …" : "Tallennetaan uuden tunnisteen nimeä…",
     "Delete tag" : "Poista tunniste",
-    "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
-    "Add default tags" : "Lisää oletustunnisteet",
-    "Add tag" : "Lisää tunniste",
-    "Saving tag …" : "Tallennetaan tunnistetta…",
     "Tag name is a hidden system tag" : "Tunnisteen nimi on piilotettu järjestelmätunniste",
     "Tag already exists" : "Tunniste on jo olemassa",
     "An error occurred, unable to create the tag." : "Tapahtui virhe, tunnistetta ei voitu luoda.",
+    "Add default tags" : "Lisää oletustunnisteet",
+    "Add tag" : "Lisää tunniste",
+    "Saving tag …" : "Tallennetaan tunnistetta…",
     "Task created" : "Tehtävä luotu",
-    "Loading thread" : "Ladataan ketjua",
-    "Not found" : "Ei löytynyt",
     "Could not load your message thread" : "Viestiketjua ei voitu ladata",
     "The thread doesn't exist or has been deleted" : "Ketjua ei ole olemassa tai se on poistettu",
-    "Unsubscribe" : "Peruuta tilaus",
+    "Loading thread" : "Ladataan ketjua",
+    "Not found" : "Ei löytynyt",
+    "Encrypted & verified " : "Salattu ja vahvistettu",
+    "Signature verified" : "Allekirjoitus vahvistettu",
+    "Signature unverified " : "Allekirjoitus vahvistamatta",
+    "This message was encrypted by the sender before it was sent." : "Tämän viestin lähettäjä salasi viestin ennen sen lähettämistä.",
     "Reply all" : "Vastaa kaikille",
+    "Unsubscribe" : "Peruuta tilaus",
     "Reply to sender only" : "Vastaa vain lähettäjälle",
     "Mark as favorite" : "Merkitse suosikiksi",
     "Mark as unread" : "Merkitse lukemattomaksi",
@@ -377,10 +387,9 @@ OC.L10N.register(
     "Archive message" : "Arkistoi viesti",
     "Delete message" : "Poista viesti",
     "Message source" : "Viestin lähde",
-    "Encrypted & verified " : "Salattu ja vahvistettu",
-    "Signature verified" : "Allekirjoitus vahvistettu",
-    "Signature unverified " : "Allekirjoitus vahvistamatta",
-    "This message was encrypted by the sender before it was sent." : "Tämän viestin lähettäjä salasi viestin ennen sen lähettämistä.",
+    "The message could not be translated" : "Viestiä ei voitu kääntää",
+    "Translation copied to clipboard" : "Käännös kopioitu leikepöydälle",
+    "Translation could not be copied" : "Käännöstä ei voitu kopioida",
     "Translate message" : "Käännä viesti",
     "Source language to translate from" : "Lähdekieli, josta käännetään",
     "Translate from" : "Lähdekieli",
@@ -388,21 +397,18 @@ OC.L10N.register(
     "Translate to" : "Kohdekieli",
     "Translating" : "Käännetään",
     "Copy translated text" : "Kopioi käännetty teksti",
-    "The message could not be translated" : "Viestiä ei voitu kääntää",
-    "Translation copied to clipboard" : "Käännös kopioitu leikepöydälle",
-    "Translation could not be copied" : "Käännöstä ei voitu kopioida",
-    "No senders are trusted at the moment." : "Ei luotettuja lähettäjiä tällä hetkellä.",
     "Could not remove trusted sender {sender}" : "Ei voitu poistaa luotettua lähettäjää {sender}",
-    "(organizer)" : "(järjestäjä)",
+    "No senders are trusted at the moment." : "Ei luotettuja lähettäjiä tällä hetkellä.",
     "Untitled event" : "Nimetön tapahtuma",
+    "(organizer)" : "(järjestäjä)",
     "Import into {calendar}" : "Tuo kalenteriin {calendar}",
     "Event imported into {calendar}" : "Tapahtuma tuotiin kalenteriin {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Lento {flightNr} lentokentältä {depAirport} lentokentälle {arrAirport}",
     "Airplane" : "Lentokone",
     "Reservation {id}" : "Varaus {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Lento {flightNr} lentokentältä {depAirport} lentokentälle {arrAirport}",
-    "Train" : "Juna",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} asemalta {depStation} asemalle {arrStation}",
     "Train from {depStation} to {arrStation}" : "Juna asemalta {depStation} asemalle {arrStation}",
+    "Train" : "Juna",
     "Flag" : "Lippu",
     "Delete filter" : "Poista suodatin",
     "Operator" : "Operaattori",
@@ -424,12 +430,12 @@ OC.L10N.register(
     "Anti Spam" : "Roskapostin esto",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Alkuperäinen viesti asetetaan \"message/rfc822\"-liitteeksi.",
     "Reset" : "Palauta",
-    "Client ID" : "Asiakas-ID",
-    "Client secret" : "Asiakassalasana",
-    "Unlink" : "Poista linkitys",
     "Google integration configured" : "Google-integraatio määritetty",
     "Could not configure Google integration" : "Google-integraatiota ei voitu määrittää",
     "Google integration unlinked" : "Google-integraation linkitys poistettu",
+    "Client ID" : "Asiakas-ID",
+    "Client secret" : "Asiakassalasana",
+    "Unlink" : "Poista linkitys",
     "Microsoft integration configured" : "Microsoft-integraatio määritetty",
     "Could not configure Microsoft integration" : "Microsoft-integraatiota ei voitu määrittää",
     "Email: {email}" : "Sähköposti: {email}",
@@ -443,6 +449,9 @@ OC.L10N.register(
     "Enable LDAP aliases integration" : "Käytä LDAP-aliasten integraatiota",
     "Save Config" : "Tallenna asetus",
     "With the settings above, the app will create account settings in the following way:" : "Sovellus luo tiliasetukset yllä olevin asetuksin seuraavasti:",
+    "Certificate imported successfully" : "Varmenne tuotu onnistuneesti",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Varmenteen tuonti epäonnistui. Varmista, että yksityinen avain vastaa varmennetta ja ettei se ole suojattu tunnuslauseella.",
+    "Failed to import the certificate" : "Varmenteen tuominen epäonnistui",
     "S/MIME certificates" : "S/MIME-varmenteet",
     "Certificate name" : "Varmenteen nimi",
     "E-mail address" : "Sähköpostiosoite",
@@ -456,17 +465,10 @@ OC.L10N.register(
     "Certificate" : "Varmenne",
     "Private key (optional)" : "Yksityinen avain (valinnainen)",
     "Submit" : "Lähetä",
-    "Certificate imported successfully" : "Varmenne tuotu onnistuneesti",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Varmenteen tuonti epäonnistui. Varmista, että yksityinen avain vastaa varmennetta ja ettei se ole suojattu tunnuslauseella.",
-    "Failed to import the certificate" : "Varmenteen tuominen epäonnistui",
     "Account connected" : "Tili yhdistetty",
     "You can close this window" : "Voit sulkea tämän ikkunan",
     "Connect your mail account" : "Yhdistä sähköpostitilisi",
     "To add a mail account, please contact your administrator." : "Ole yhteydessä ylläpitoon lisätäksesi sähköpostitilin.",
-    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
-    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
-    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
     "All" : "Kaikki",
     "Drafts" : "Luonnokset",
     "Favorites" : "Suosikit",
@@ -497,7 +499,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klikkaa jos sinua ei uudelleenohjata automaattisesti muutamaan sekuntiin.",
     "Redirect" : "Uudelleenohjaus",
     "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
-    "Continue to %s" : "Jatka sivulle %s",
-    "Unselect" : "Poista valinta"
+    "Continue to %s" : "Jatka sivulle %s"
 },
 "nplurals=2; plural=(n != 1);");
