@@ -16,6 +16,12 @@ OC.L10N.register(
     "Drafts are saved in:" : "Os rascunhos são guardados em:",
     "Sent messages are saved in:" : "As mensagens enviadas são guardadas em:",
     "Deleted messages are moved in:" : "Deleted messages are moved in:",
+    "Connecting" : "A ligar",
+    "Reconnect Google account" : "Religar conta Google",
+    "Reconnect Microsoft account" : "Religar conta Microsoft",
+    "Save" : "Guardar",
+    "Connect" : "Ligar",
+    "Password required" : "Necessário palavra-passe",
     "Auto" : "Auto",
     "Name" : "Nome",
     "Password" : "Palavra-passe",
@@ -35,12 +41,6 @@ OC.L10N.register(
     "SMTP Port" : "Porto SMTP",
     "SMTP User" : "Utilizador SMTP",
     "SMTP Password" : "Palavra-passe SMTP",
-    "Connecting" : "A ligar",
-    "Reconnect Google account" : "Religar conta Google",
-    "Reconnect Microsoft account" : "Religar conta Microsoft",
-    "Save" : "Guardar",
-    "Connect" : "Ligar",
-    "Password required" : "Necessário palavra-passe",
     "Account settings" : "Definições da conta",
     "Signature" : "Assinatura",
     "A signature is added to the text of new messages and replies." : "A assinatura é adicionada ao texto das novas mensagens e respostas.",
@@ -60,6 +60,7 @@ OC.L10N.register(
     "Register as application for mail links" : "Registar como aplicação para ligações de correio",
     "Register" : "Registar",
     "Trusted senders" : "Remetentes confiáveis",
+    "About" : "Sobre",
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Compose new message" : "Compor nova mensagem",
     "Archive" : "Arquivar",
@@ -83,11 +84,12 @@ OC.L10N.register(
     "Add attachment from Files" : "Adicionar anexo a partir dos ficheiros",
     "Request a read receipt" : "Solicitar um recibo de leitura",
     "Encrypt message with Mailvelope" : "Cifrar a mensagem com Mailvelope",
-    "Choose a file to add as attachment" : "Escolha um ficheiro para adicionar como anexo",
     "Choose" : "Escolher",
+    "Choose a file to add as attachment" : "Escolha um ficheiro para adicionar como anexo",
     "Confirm" : "Confirmar",
     "Plain text" : "Texto simples",
     "No messages" : "Sem mensagens",
+    "Could not delete message" : "Não foi possível apagar a mensagem",
     "Draft: " : "Rascunho:",
     "Unfavorite" : "Não favorito",
     "Favorite" : "Favorito",
@@ -99,20 +101,19 @@ OC.L10N.register(
     "Edit as new message" : "Editar como nova mensagem",
     "Create event" : "Criar evento",
     "Download message" : "Transferir mensagem",
-    "Could not delete message" : "Não foi possível apagar a mensagem",
     "Load more" : "Carregar mais",
+    "Could not create event" : "Não foi possível criar o evento",
     "All day" : "Todo o dia",
     "Description" : "Descrição",
     "Create" : "Criar",
-    "Could not create event" : "Não foi possível criar o evento",
     "Select" : "Selecionar",
     "Comment" : "Comentário",
     "Accept" : "Aceitar",
     "Decline" : "Recusar",
+    "individual" : "individual",
     "domain" : "domínio",
     "Remove" : "Remover",
     "email" : "email",
-    "individual" : "individual",
     "Important info" : "Informação importante",
     "Other" : "Outro",
     "Notify the sender" : "Notificar o remetente",
@@ -120,12 +121,12 @@ OC.L10N.register(
     "Translate" : "Traduzir",
     "View source" : "Ver fonte",
     "Message body" : "Corpo da mensagem",
+    "Unnamed" : "Sem nome",
+    "Embedded message" : "Mensagem embebida",
     "Choose a folder to store the attachment in" : "Escolha uma pasta para guardar o anexo",
     "Import into calendar" : "Importar para o calendário",
     "Download attachment" : "Transferir anexo",
     "Save to Files" : "Guardar em Ficheiros",
-    "Unnamed" : "Sem nome",
-    "Embedded message" : "Mensagem embebida",
     "Choose a folder to store the attachments in" : "Escolha uma pasta para armazenar anexos",
     "Save all to Files" : "Guardar todos em Ficheiros",
     "Download Zip" : "Transferir Zip",
@@ -136,16 +137,16 @@ OC.L10N.register(
     "Always show images from {domain}" : "Mostrar sempre as imagem de {domain}",
     "Move" : "Mover",
     "Moving" : "A mover",
+    "Loading …" : "A carregar...",
+    "Not supported by the server" : "Não é suportado pelo servidor",
+    "{usage} of {limit} used" : "Usado {usage}  {limit}",
+    "Remove account" : "Remover conta",
+    "Remove {email}" : "Remover {email}",
     "Quota" : "Quota",
     "Add mailbox" : "Adicionar caixa de",
     "Saving" : "A guardar",
     "Move up" : "Mover para cima",
     "Move down" : "Mover para baixo",
-    "Remove account" : "Remover conta",
-    "Loading …" : "A carregar...",
-    "Not supported by the server" : "Não é suportado pelo servidor",
-    "{usage} of {limit} used" : "Usado {usage}  {limit}",
-    "Remove {email}" : "Remover {email}",
     "Show all mailboxes" : "Mostrar todas as caixas de entrada",
     "Mark all as read" : "Marcar todas como lidas",
     "Rename" : "Renomear",
@@ -153,13 +154,13 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Limpe a cache de dados local no caso de ter problemas com a sincronização.",
     "Subscribed" : "Subscrito",
     "New message" : "Nova mensagem",
+    "Reply" : "Resposta",
     "Error sending your message" : "Erro ao enviar a sua mensagem",
     "Retry" : "Repetir",
     "Uploading attachments …" : "A enviar anexos ...",
     "Sending …" : "A enviar...",
     "Warning sending your message" : "Aviso ao enviar a sua mensagem",
     "Send anyway" : "Enviar de qualquer maneira",
-    "Reply" : "Resposta",
     "Message" : "Mensagem",
     "Contacts with this address" : "Contactos com este endereço",
     "Add to Contact" : "Adicionar aos contactos",
@@ -167,11 +168,11 @@ OC.L10N.register(
     "Copy to clipboard" : "Copiar para área de transferência",
     "Contact name …" : "Nome do contacto...",
     "Add" : "Adicionar",
+    "Clear" : "Limpar",
     "Close" : "Fechar",
     "Body" : "Corpo",
     "Date" : "Data",
     "Tags" : "Etiquetas",
-    "Clear" : "Limpar",
     "Custom" : "Personalizado",
     "Signature …" : "Assinatura...",
     "Save signature" : "Guardar assinatura",
@@ -225,7 +226,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redirecionado dentro de segundos.",
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "A ligação aponta para %s",
-    "Continue to %s" : "Continuar para %s",
-    "Unselect" : "Não selecionar"
+    "Continue to %s" : "Continuar para %s"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
