@@ -12,7 +12,8 @@ use OCA\Mail\Contracts\IMailTransmission;
 use OCA\Mail\Db\LocalMessage;
 
 class SendHandler extends AHandler {
-	public function __construct(private IMailTransmission $transmission,
+	public function __construct(
+		private IMailTransmission $transmission,
 	) {
 	}
 
