@@ -66,7 +66,7 @@ class MailTransmission implements IMailTransmission {
 		private LoggerInterface $logger,
 		private PerformanceLogger $performanceLogger,
 		private AliasesService $aliasesService,
-		private TransmissionService $transmissionService
+		private TransmissionService $transmissionService,
 	) {
 	}
 
@@ -122,9 +122,10 @@ class MailTransmission implements IMailTransmission {
 			new DataUriParser()
 		);
 		$mimePart = $mimeMessage->build(
-			$localMessage->isHtml(),
-			$localMessage->getBody(),
-			$attachmentParts
+			$localMessage->getBodyPlain(),
+			$localMessage->getBodyHtml(),
+			$attachmentParts,
+			$localMessage->isPgpMime() === true
 		);
 
 		// TODO: add smimeEncrypt check if implemented
@@ -142,6 +143,7 @@ class MailTransmission implements IMailTransmission {
 		try {
 			$mail->send($transport, false, false);
 			$localMessage->setRaw($mail->getRaw(false));
+			$localMessage->setStatus(LocalMessage::STATUS_RAW);
 		} catch (Horde_Mime_Exception $e) {
 			$this->logger->error($e->getMessage(), ['exception' => $e]);
 			if (in_array($e->getCode(), self::RETRIABLE_CODES, true)) {
@@ -182,7 +184,11 @@ class MailTransmission implements IMailTransmission {
 		$imapMessage->setFrom($from);
 		$imapMessage->setCC($cc);
 		$imapMessage->setBcc($bcc);
-		$imapMessage->setContent($message->getBody());
+		if ($message->isHtml() === true) {
+			$imapMessage->setContent($message->getBodyHtml());
+		} else {
+			$imapMessage->setContent($message->getBodyPlain());
+		}
 
 		foreach ($attachments as $attachment) {
 			$this->transmissionService->handleAttachment($account, $attachment);
@@ -348,7 +354,7 @@ class MailTransmission implements IMailTransmission {
 		}
 
 		if (count($fetchResults) < 1) {
-			throw new ServiceException('Message "' .$message->getId() . '" not found.');
+			throw new ServiceException('Message "' . $message->getId() . '" not found.');
 		}
 
 		$imapDate = $fetchResults[0]->getImapDate();
@@ -360,7 +366,7 @@ class MailTransmission implements IMailTransmission {
 		$originalRecipient = $mdnHeaders->getHeader('original-recipient');
 
 		if ($dispositionNotificationTo === null) {
-			throw new ServiceException('Message "' .$message->getId() . '" has no disposition-notification-to header.');
+			throw new ServiceException('Message "' . $message->getId() . '" has no disposition-notification-to header.');
 		}
 
 		$headers = new Horde_Mime_Headers();
